.. tracksegnet documentation master file, created by
   sphinx-quickstart on Fri Feb 16 23:09:32 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to TrackSegNet's documentation!
=======================================

Segmentation of trajectories into diffusive states using supervised LSTM network.

.. toctree::
   :maxdepth: 1
   :caption: TrackSegNet:

   purposes
   installation
   data-preparation
   run-instruction
   analysis-plots

.. toctree::
   :maxdepth: 1
   :caption: Modules:

   simulate_tracks
   experimental_tracks
   compute_features
   generate_lstm_model
   analysis
   utils

.. toctree::
   :maxdepth: 1
   :caption: Contributing:

   contributing
